@@ -2,17 +2,17 @@
 extern crate redis_module;
 
 use redis_module::raw::KeyType;
-use redis_module::{Context, NextArg, RedisError, RedisResult, RedisValue};
+use redis_module::{Context, NextArg, RedisError, RedisResult, RedisString, RedisValue};
 
 // LPOPRPUSH source destination
 // Pops and returns the first element (head) of the list stored at 'source'
 // and pushes the element to the last position (tail) of the list stored at
 // 'destination'.
-fn lpoprpush(ctx: &Context, args: Vec<String>) -> RedisResult {
+fn lpoprpush(ctx: &Context, args: Vec<RedisString>) -> RedisResult {
     let mut args = args.into_iter().skip(1);
 
-    let src = args.next_string()?;
-    let dst = args.next_string()?;
+    let src = args.next_arg()?;
+    let dst = args.next_arg()?;
 
     let src_key = ctx.open_key_writable(&src);
     let dst_key = ctx.open_key_writable(&dst);
